pub struct Value(ShortBoxSlice<Subtag>);Expand description
A value used in a list of Keywords.
The value has to be a sequence of one or more alphanumerical strings
separated by -.
Each part of the sequence has to be no shorter than three characters and no
longer than 8.
Examples
use icu::locale::extensions::unicode::{Value, value};
use writeable::assert_writeable_eq;
assert_writeable_eq!(value!("gregory"), "gregory");
assert_writeable_eq!(
"islamic-civil".parse::<Value>().unwrap(),
"islamic-civil"
);
// The value "true" has the special, empty string representation
assert_eq!(value!("true").to_string(), "");Tuple Fields
0: ShortBoxSlice<Subtag>Implementations
Sourceimpl Value
impl Value
Sourcepub fn try_from_str(s: &str) -> Result<Self, ParseError>
pub fn try_from_str(s: &str) -> Result<Self, ParseError>
A constructor which str slice, parses it and
produces a well-formed Value.
Examples
use icu::locale::extensions::unicode::Value;
Value::try_from_str("buddhist").expect("Parsing failed.");alloc Cargo feature
Without the alloc Cargo feature, this only supports parsing
up to two (non-true) subtags, and will return an error for
longer strings.
Sourcepub fn try_from_utf8(code_units: &[u8]) -> Result<Self, ParseError>
pub fn try_from_utf8(code_units: &[u8]) -> Result<Self, ParseError>
Sourcepub const fn as_single_subtag(&self) -> Option<&Subtag>
pub const fn as_single_subtag(&self) -> Option<&Subtag>
Returns a reference to a single Subtag if the Value contains exactly one
subtag, or None otherwise.
Examples
use core::str::FromStr;
use icu::locale::extensions::unicode::Value;
let value1 = Value::from_str("foo").expect("failed to parse a Value");
let value2 = Value::from_str("foo-bar").expect("failed to parse a Value");
assert!(value1.as_single_subtag().is_some());
assert!(value2.as_single_subtag().is_none());Sourcepub fn into_single_subtag(self) -> Option<Subtag>
pub fn into_single_subtag(self) -> Option<Subtag>
Destructs into a single Subtag if the Value contains exactly one
subtag, or returns None otherwise.
Examples
use core::str::FromStr;
use icu::locale::extensions::unicode::Value;
let value1 = Value::from_str("foo").expect("failed to parse a Value");
let value2 = Value::from_str("foo-bar").expect("failed to parse a Value");
assert!(value1.into_single_subtag().is_some());
assert!(value2.into_single_subtag().is_none());Sourcepub fn push_subtag(&mut self, subtag: Subtag)
pub fn push_subtag(&mut self, subtag: Subtag)
Appends a subtag to the back of a Value.
✨ Enabled with the alloc Cargo feature.
Examples
use icu::locale::{extensions::unicode::Value, subtags::subtag};
let mut v = Value::default();
v.push_subtag(subtag!("foo"));
// The `true` subtag is ignored
v.push_subtag(subtag!("true"));
v.push_subtag(subtag!("bar"));
assert_eq!(v, "foo-bar");Sourcepub fn subtag_count(&self) -> usize
pub fn subtag_count(&self) -> usize
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the Value has no subtags.
Examples
use icu::locale::{extensions::unicode::Value, subtags::subtag};
let mut v = Value::default();
assert!(v.is_empty());Sourcepub fn remove_subtag(&mut self, idx: usize) -> Option<Subtag>
pub fn remove_subtag(&mut self, idx: usize) -> Option<Subtag>
Removes and returns the subtag at position index within the value,
shifting all subtags after it to the left.
Examples
use icu::locale::{extensions::unicode::Value, subtags::subtag};
let mut v = Value::default();
v.push_subtag(subtag!("foo"));
v.push_subtag(subtag!("bar"));
v.push_subtag(subtag!("baz"));
assert_eq!(v.remove_subtag(1), Some(subtag!("bar")));
assert_eq!(v, "foo-baz");Sourcepub fn get_subtag(&self, idx: usize) -> Option<&Subtag>
pub fn get_subtag(&self, idx: usize) -> Option<&Subtag>
Returns a reference to a subtag at index.
Examples
use icu::locale::{extensions::unicode::Value, subtags::subtag};
let mut v = Value::default();
v.push_subtag(subtag!("foo"));
v.push_subtag(subtag!("bar"));
v.push_subtag(subtag!("baz"));
assert_eq!(v.get_subtag(1), Some(&subtag!("bar")));
assert_eq!(v.get_subtag(3), None);Sourcepub fn from_vec_unchecked(input: Vec<Subtag>) -> Self
pub fn from_vec_unchecked(input: Vec<Subtag>) -> Self
A constructor which takes a pre-sorted list of Value elements.
✨ Enabled with the alloc Cargo feature.
Examples
use icu::locale::extensions::unicode::Value;
use icu::locale::subtags::subtag;
let subtag1 = subtag!("foobar");
let subtag2 = subtag!("testing");
let mut v = vec![subtag1, subtag2];
v.sort();
v.dedup();
let value = Value::from_vec_unchecked(v);Notice: For performance- and memory-constrained environments, it is recommended
for the caller to use binary_search instead of sort
and dedup.
pub(crate) fn from_short_slice_unchecked(input: ShortBoxSlice<Subtag>) -> Self
pub(crate) const fn parse_subtag_from_utf8( t: &[u8], ) -> Result<Option<Subtag>, ParseError>
pub(crate) fn for_each_subtag_str<E, F>(&self, f: &mut F) -> Result<(), E>